# keymouse

Python module to work with keyboard and mouse.
Consist of pynput and pyautogui modules but with modifications to be crossplatform and without bugs when you use different layouts

## Ubuntu depedencies

Install xclip ```sudo apt-get install xclip```
